import setuptools
setuptools.setup(
    name='AziizAM',
    version='0.0.2',
    author="A.Alminqah",
    author_email="A.Alminqah@hotmail.com",
    description="Fast way to access my custom python function.",
    url="https://github.com/AziizMq/AziizAM-Pypi",
    project_urls={
        'Tracker': 'https://github.com/AziizMq/AziizAM-Pypi/issues',
    },
    packages=setuptools.find_packages(),
    classifiers=[
    "Programming Language :: Python :: 3",
    "License :: OSI Approved :: MIT License",
    "Operating System :: OS Independent",
    ],
)
